==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/cs-CZ/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Potvrzení hromadného odstranění majetku',
    'bulk_restore'      => 'Potvrzení hromadného obnovení majetku', 
  'bulk_delete_help'	=> 'Zkontrolujte seznam odstraňovaného majetku níže. Jakmile jej potvrdíte, nebude možné tento majetek obnovit a budou zrušeny i vazby na uživatele, kteří jej měli v držení.',
  'bulk_restore_help'	=> 'Níže zkontrolujte majetek před jeho hromadnou obnovou. Po obnovení nebude majetek spojen s žádnými uživateli, kterým byl dříve přidělen.',
  'bulk_delete_warn'	=> 'Chystáte se odstranit :asset_count položek majetku.',
  'bulk_restore_warn'	=> 'Chystáte se obnovit :asset_count položek majetku.',
    'bulk_update'		=> 'Hromadná aktualizace majetku',
    'bulk_update_help'	=> 'Tento formulář umožňuje hromadnou editaci majetku. Vyplňte pouze položky, které chcete změnit. Jakékoliv prázné položky zůstanou nezměněny. ',
    'bulk_update_warn'	=> 'Chystáte se upravit vlastnosti 1 položky.|Chystáte se upravit vlastnosti :asset_count položek.',
    'bulk_update_with_custom_field' => 'Upozorňujeme, že aktiva jsou :asset_model_count různých typů modelů.',
    'bulk_update_model_prefix' => 'Na modelech', 
    'bulk_update_custom_field_unique' => 'Toto je unikátní pole a nemůže být hromadně upravováno.',
    'checkedout_to'		=> 'Vydané komu',
    'checkout_date'		=> 'Datum vydání',
    'checkin_date'		=> 'Datum převzetí',
    'checkout_to'		=> 'Vydat někomu',
    'cost'				=> 'Pořizovací cena',
    'create'			=> 'Vytvořit záznam majetku',
    'date'				=> 'Datum pořízení',
    'depreciation'	    => 'Amortizace',
    'depreciates_on'	=> 'Odepisuje se',
    'default_location'	=> 'Výchozí umístění',
    'default_location_phone' => 'Výchozí telefon',
    'eol_date'			=> 'Konec životnosti',
    'eol_rate'			=> 'Míra ukončení životnosti',
    'expected_checkin'  => 'Očekávané datum převzetí',
    'expires'			=> 'Expiruje',
    'fully_depreciated'	=> 'Plně odepsané',
    'help_checkout'		=> 'Přejete-li si přiřadit toto zařízení okamžitě, zvolte "Připraveno k předání" ze seznamu níže. ',
    'mac_address'		=> 'MAC adresa',
    'manufacturer'		=> 'Výrobce',
    'model'				=> 'Model',
    'months'			=> 'měsíce',
    'name'				=> 'Název majetku',
    'notes'				=> 'Poznámky',
    'order'				=> 'Č. objednávky',
    'qr'				=> 'QR kód',
    'requestable'		=> 'Uživatelé můžou požádat o tento majetek',
    'select_statustype'	=> 'Zvolte typ stavu',
    'serial'			=> 'Sériové číslo',
    'status'			=> 'Stav',
    'tag'				=> 'Označení majetku',
    'update'			=> 'Úprava majetku',
    'warranty'			=> 'Záruka',
        'warranty_expires'		=> 'Záruka končí',
    'years'				=> 'roky',
    'asset_location' => 'Upravit umístění',
    'asset_location_update_default_current' => 'Aktualizovat výchozí umístění A aktuální umístění',
    'asset_location_update_default' => 'Aktualizovat pouze výchozí umístění',
    'asset_location_update_actual' => 'Aktualizovat pouze skutečnou polohu',
    'asset_not_deployable' => 'Tento majetek nelze vyskladnit.',
    'asset_deployable' => 'Tento majetek lze vyskladnit.',
    'processing_spinner' => 'Zpracovávání... (S velkými soubory to může chvíli trvat)',
    'optional_infos'  => 'Volitelné informace',
    'order_details'   => 'Informace související s objednávkou'
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/cs-CZ/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Potvrzení hromadného odstranění majetku',
    'bulk_restore'      => 'Potvrzení hromadného obnovení majetku', 
  'bulk_delete_help'	=> 'Zkontrolujte seznam odstraňovaného majetku níže. Jakmile jej potvrdíte, nebude možné tento majetek obnovit a budou zrušeny i vazby na uživatele, kteří jej měli v držení.',
  'bulk_restore_help'	=> 'Níže zkontrolujte majetek před jeho hromadnou obnovou. Po obnovení nebude majetek spojen s žádnými uživateli, kterým byl dříve přidělen.',
  'bulk_delete_warn'	=> 'Chystáte se odstranit :asset_count položek majetku.',
  'bulk_restore_warn'	=> 'Chystáte se obnovit :asset_count položek majetku.',
    'bulk_update'		=> 'Hromadná aktualizace majetku',
    'bulk_update_help'	=> 'Tento formulář umožňuje hromadnou editaci majetku. Vyplňte pouze položky, které chcete změnit. Jakékoliv prázné položky zůstanou nezměněny. ',
    'bulk_update_warn'	=> 'Chystáte se upravit vlastnosti 1 položky.|Chystáte se upravit vlastnosti :asset_count položek.',
    'bulk_update_with_custom_field' => 'Upozorňujeme, že aktiva jsou :asset_model_count různých typů modelů.',
    'bulk_update_model_prefix' => 'Na modelech', 
    'bulk_update_custom_field_unique' => 'Toto je unikátní pole a nemůže být hromadně upravováno.',
    'checkedout_to'		=> 'Vydané komu',
    'checkout_date'		=> 'Datum vydání',
    'checkin_date'		=> 'Datum převzetí',
    'checkout_to'		=> 'Vydat někomu',
    'cost'				=> 'Pořizovací cena',
    'create'			=> 'Vytvořit záznam majetku',
    'date'				=> 'Datum pořízení',
    'depreciation'	    => 'Amortizace',
    'depreciates_on'	=> 'Odepisuje se',
    'default_location'	=> 'Výchozí umístění',
    'default_location_phone' => 'Výchozí telefon',
    'eol_date'			=> 'Konec životnosti',
    'eol_rate'			=> 'Míra ukončení životnosti',
    'expected_checkin'  => 'Očekávané datum převzetí',
    'expires'			=> 'Expiruje',
    'fully_depreciated'	=> 'Plně odepsané',
    'help_checkout'		=> 'Přejete-li si přiřadit toto zařízení okamžitě, zvolte "Připraveno k předání" ze seznamu níže. ',
    'mac_address'		=> 'MAC adresa',
    'manufacturer'		=> 'Výrobce',
    'model'				=> 'Model',
    'months'			=> 'měsíce',
    'name'				=> 'Název majetku',
    'notes'				=> 'Poznámky',
    'order'				=> 'Č. objednávky',
    'qr'				=> 'QR kód',
    'requestable'		=> 'Uživatelé můžou požádat o tento majetek',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Zvolte typ stavu',
    'serial'			=> 'Sériové číslo',
    'status'			=> 'Stav',
    'tag'				=> 'Označení majetku',
    'update'			=> 'Úprava majetku',
    'warranty'			=> 'Záruka',
        'warranty_expires'		=> 'Záruka končí',
    'years'				=> 'roky',
    'asset_location' => 'Upravit umístění',
    'asset_location_update_default_current' => 'Aktualizovat výchozí umístění A aktuální umístění',
    'asset_location_update_default' => 'Aktualizovat pouze výchozí umístění',
    'asset_location_update_actual' => 'Aktualizovat pouze skutečnou polohu',
    'asset_not_deployable' => 'Tento majetek nelze vyskladnit.',
    'asset_deployable' => 'Tento majetek lze vyskladnit.',
    'processing_spinner' => 'Zpracovávání... (S velkými soubory to může chvíli trvat)',
    'optional_infos'  => 'Volitelné informace',
    'order_details'   => 'Informace související s objednávkou'
];
